summaryrefslogtreecommitdiff
path: root/jstests/noPassthroughWithMongod
diff options
context:
space:
mode:
authorYuhong Zhang <yuhong.zhang@mongodb.com>2022-08-25 13:57:20 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2022-08-25 14:44:30 +0000
commiteaa4652ee9eef8c206573e90e6ab16831758078c (patch)
treeca7fcc6c75eb8c322cb9c6c5a11181568567b6f9 /jstests/noPassthroughWithMongod
parentfefcf3b895f2650ca2df12f3d15f4fa55569c95a (diff)
downloadmongo-eaa4652ee9eef8c206573e90e6ab16831758078c.tar.gz
SERVER-68688 Rename `checkBSONConsistency` option to `checkBSONConformance`
Diffstat (limited to 'jstests/noPassthroughWithMongod')
-rw-r--r--jstests/noPassthroughWithMongod/validate_checkBSONConformance.js (renamed from jstests/noPassthroughWithMongod/validate_checkBSONConsistency.js)18
1 files changed, 9 insertions, 9 deletions
diff --git a/jstests/noPassthroughWithMongod/validate_checkBSONConsistency.js b/jstests/noPassthroughWithMongod/validate_checkBSONConformance.js
index dab1163cc40..c95c9c0bef8 100644
--- a/jstests/noPassthroughWithMongod/validate_checkBSONConsistency.js
+++ b/jstests/noPassthroughWithMongod/validate_checkBSONConformance.js
@@ -1,5 +1,5 @@
/*
* Tests the usage of 'checkBSONConsistency' option of the validate command.
*
* @tags: [featureFlagExtendValidateCommand]
*/
@@ -7,32 +7,32 @@
(function() {
"use strict";
-const collName = "validate_checkBSONConsistency";
+const collName = "validate_checkBSONConformance";
const coll = db.getCollection(collName);
coll.drop();
assert.commandWorked(coll.insert({a: 1}));
assert.commandFailedWithCode(
- db.runCommand({validate: collName, checkBSONConsistency: true, metadata: true}),
+ db.runCommand({validate: collName, checkBSONConformance: true, metadata: true}),
ErrorCodes.InvalidOptions);
assert.commandFailedWithCode(
- db.runCommand({validate: collName, checkBSONConsistency: true, repair: true}),
+ db.runCommand({validate: collName, checkBSONConformance: true, repair: true}),
ErrorCodes.InvalidOptions);
assert.commandWorked(
- db.runCommand({validate: collName, checkBSONConsistency: true, background: true}));
+ db.runCommand({validate: collName, checkBSONConformance: true, background: true}));
assert.commandFailedWithCode(
- db.runCommand({validate: collName, checkBSONConsistency: false, full: true}),
+ db.runCommand({validate: collName, checkBSONConformance: false, full: true}),
ErrorCodes.InvalidOptions);
-assert.commandWorked(db.runCommand({validate: collName, checkBSONConsistency: true, full: true}));
+assert.commandWorked(db.runCommand({validate: collName, checkBSONConformance: true, full: true}));
assert.commandFailedWithCode(
- db.runCommand({validate: collName, checkBSONConsistency: false, enforceFastCount: true}),
+ db.runCommand({validate: collName, checkBSONConformance: false, enforceFastCount: true}),
ErrorCodes.InvalidOptions);
assert.commandWorked(
- db.runCommand({validate: collName, checkBSONConsistency: true, enforceFastCount: true}));
+ db.runCommand({validate: collName, checkBSONConformance: true, enforceFastCount: true}));
})();
@@ -1,5 +1,5 @@
/*
- * Tests the usage of 'checkBSONConsistency' option of the validate command.
+ * Tests the usage of 'checkBSONConformance' option of the validate command.
*
* @tags: [featureFlagExtendValidateCommand]